==> SCFiler2-0.10.zip: SCFiler2/SCFiler2/OptionDialog.Designer.cs <==
﻿namespace SCFiler2 {
	partial class OptionDialog {
		/// <summary>
		/// 必要なデザイナ変数です。
		/// </summary>
		private System.ComponentModel.IContainer components = null;

		/// <summary>
		/// 使用中のリソースをすべてクリーンアップします。
		/// </summary>
		/// <param name="disposing">マネージ リソースが破棄される場合 true、破棄されない場合は false です。</param>
		protected override void Dispose(bool disposing) {
			if (disposing && (components != null)) {
				components.Dispose();
			}
			base.Dispose(disposing);
		}

		#region Windows フォーム デザイナで生成されたコード

		/// <summary>
		/// デザイナ サポートに必要なメソッドです。このメソッドの内容を
		/// コード エディタで変更しないでください。
		/// </summary>
		private void InitializeComponent() {
			this.tabControl1 = new System.Windows.Forms.TabControl();
			this.tabPage1 = new System.Windows.Forms.TabPage();
			this.tabPage2 = new System.Windows.Forms.TabPage();
			this.assign_button = new System.Windows.Forms.Button();
			this.label2 = new System.Windows.Forms.Label();
			this.label1 = new System.Windows.Forms.Label();
			this.new_key = new System.Windows.Forms.TextBox();
			this.old_key = new System.Windows.Forms.TextBox();
			this.action_list = new System.Windows.Forms.ListView();
			this.tabPage3 = new System.Windows.Forms.TabPage();
			this.tabPage4 = new System.Windows.Forms.TabPage();
			this.label5 = new System.Windows.Forms.Label();
			this.label4 = new System.Windows.Forms.Label();
			this.label3 = new System.Windows.Forms.Label();
			this.historyview2_valid_string = new System.Windows.Forms.TextBox();
			this.historyview1_valid_string = new System.Windows.Forms.TextBox();
			this.cancel_button = new System.Windows.Forms.Button();
			this.ok_button = new System.Windows.Forms.Button();
			this.tabControl1.SuspendLayout();
			this.tabPage2.SuspendLayout();
			this.tabPage4.SuspendLayout();
			this.SuspendLayout();
			// 
			// tabControl1
			// 
			this.tabControl1.Controls.Add(this.tabPage1);
			this.tabControl1.Controls.Add(this.tabPage2);
			this.tabControl1.Controls.Add(this.tabPage3);
			this.tabControl1.Controls.Add(this.tabPage4);
			this.tabControl1.Dock = System.Windows.Forms.DockStyle.Top;
			this.tabControl1.Location = new System.Drawing.Point(0, 0);
			this.tabControl1.Name = "tabControl1";
			this.tabControl1.SelectedIndex = 0;
			this.tabControl1.Size = new System.Drawing.Size(576, 273);
			this.tabControl1.TabIndex = 0;
			// 
			// tabPage1
			// 
			this.tabPage1.Location = new System.Drawing.Point(4, 21);
			this.tabPage1.Name = "tabPage1";
			this.tabPage1.Padding = new System.Windows.Forms.Padding(3);
			this.tabPage1.Size = new System.Drawing.Size(568, 248);
			this.tabPage1.TabIndex = 0;
			this.tabPage1.Text = "一般設定";
			this.tabPage1.UseVisualStyleBackColor = true;
			// 
			// tabPage2
			// 
			this.tabPage2.Controls.Add(this.assign_button);
			this.tabPage2.Controls.Add(this.label2);
			this.tabPage2.Controls.Add(this.label1);
			this.tabPage2.Controls.Add(this.new_key);
			this.tabPage2.Controls.Add(this.old_key);
			this.tabPage2.Controls.Add(this.action_list);
			this.tabPage2.Location = new System.Drawing.Point(4, 21);
			this.tabPage2.Name = "tabPage2";
			this.tabPage2.Padding = new System.Windows.Forms.Padding(3);
			this.tabPage2.Size = new System.Drawing.Size(568, 248);
			this.tabPage2.TabIndex = 1;
			this.tabPage2.Text = "キー割り当て(1)";
			this.tabPage2.UseVisualStyleBackColor = true;
			// 
			// assign_button
			// 
			this.assign_button.Location = new System.Drawing.Point(443, 140);
			this.assign_button.Name = "assign_button";
			this.assign_button.Size = new System.Drawing.Size(75, 23);
			this.assign_button.TabIndex = 5;
			this.assign_button.Text = "割り当て(&A)";
			this.assign_button.UseVisualStyleBackColor = true;
			this.assign_button.Click += new System.EventHandler(this.assign_button_Click);
			// 
			// label2
			// 
			this.label2.AutoSize = true;
			this.label2.Location = new System.Drawing.Point(300, 100);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(102, 12);
			this.label2.TabIndex = 4;
			this.label2.Text = "新しく割り当てるキー";
			// 
			// label1
			// 
			this.label1.AutoSize = true;
			this.label1.Location = new System.Drawing.Point(300, 28);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(137, 12);
			this.label1.TabIndex = 3;
			this.label1.Text = "現在割り当てられているキー";
			// 
			// new_key
			// 
			this.new_key.ImeMode = System.Windows.Forms.ImeMode.Off;
			this.new_key.Location = new System.Drawing.Point(302, 115);
			this.new_key.Name = "new_key";
			this.new_key.Size = new System.Drawing.Size(216, 19);
			this.new_key.TabIndex = 2;
			this.new_key.KeyPress += new System.Windows.Forms.KeyPressEventHandler(this.new_key_KeyPress);
			this.new_key.TextChanged += new System.EventHandler(this.new_key_TextChanged);
			this.new_key.KeyDown += new System.Windows.Forms.KeyEventHandler(this.new_key_KeyDown);
			// 
			// old_key
			// 
			this.old_key.Location = new System.Drawing.Point(302, 43);
			this.old_key.Name = "old_key";
			this.old_key.Size = new System.Drawing.Size(216, 19);
			this.old_key.TabIndex = 1;
			// 
			// action_list
			// 
			this.action_list.FullRowSelect = true;
			this.action_list.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.None;
			this.action_list.HideSelection = false;
			this.action_list.LabelWrap = false;
			this.action_list.Location = new System.Drawing.Point(8, 43);
			this.action_list.MultiSelect = false;
			this.action_list.Name = "action_list";
			this.action_list.Size = new System.Drawing.Size(256, 189);
			this.action_list.TabIndex = 0;
			this.action_list.UseCompatibleStateImageBehavior = false;
			this.action_list.View = System.Windows.Forms.View.Details;
			this.action_list.SelectedIndexChanged += new System.EventHandler(this.action_list_SelectedIndexChanged);
			// 
			// tabPage3
			// 
			this.tabPage3.Location = new System.Drawing.Point(4, 21);
			this.tabPage3.Name = "tabPage3";
			this.tabPage3.Padding = new System.Windows.Forms.Padding(3);
			this.tabPage3.Size = new System.Drawing.Size(568, 248);
			this.tabPage3.TabIndex = 2;
			this.tabPage3.Text = "キー割り当て(2)";
			this.tabPage3.UseVisualStyleBackColor = true;
			// 
			// tabPage4
			// 
			this.tabPage4.Controls.Add(this.label5);
			this.tabPage4.Controls.Add(this.label4);
			this.tabPage4.Controls.Add(this.label3);
			this.tabPage4.Controls.Add(this.historyview2_valid_string);
			this.tabPage4.Controls.Add(this.historyview1_valid_string);
			this.tabPage4.Location = new System.Drawing.Point(4, 21);
			this.tabPage4.Name = "tabPage4";
			this.tabPage4.Padding = new System.Windows.Forms.Padding(3);
			this.tabPage4.Size = new System.Drawing.Size(568, 248);
			this.tabPage4.TabIndex = 3;
			this.tabPage4.Text = "履歴ビュー";
			this.tabPage4.UseVisualStyleBackColor = true;
			// 
			// label5
			// 
			this.label5.AutoSize = true;
			this.label5.Location = new System.Drawing.Point(8, 81);
			this.label5.Name = "label5";
			this.label5.Size = new System.Drawing.Size(61, 12);
			this.label5.TabIndex = 4;
			this.label5.Text = "履歴ビュー2";
			// 
			// label4
			// 
			this.label4.AutoSize = true;
			this.label4.Location = new System.Drawing.Point(8, 37);
			this.label4.Name = "label4";
			this.label4.Size = new System.Drawing.Size(61, 12);
			this.label4.TabIndex = 3;
			this.label4.Text = "履歴ビュー1";
			// 
			// label3
			// 
			this.label3.AutoSize = true;
			this.label3.Location = new System.Drawing.Point(8, 12);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(456, 12);
			this.label3.TabIndex = 2;
			this.label3.Text = "履歴ビューへ登録する拡張子（セミコロン(;)区切りで、ドット付きで記入してください）　例：.mp3;.txt";
			// 
			// historyview2_valid_string
			// 
			this.historyview2_valid_string.Location = new System.Drawing.Point(8, 96);
			this.historyview2_valid_string.Name = "historyview2_valid_string";
			this.historyview2_valid_string.Size = new System.Drawing.Size(551, 19);
			this.historyview2_valid_string.TabIndex = 1;
			// 
			// historyview1_valid_string
			// 
			this.historyview1_valid_string.Location = new System.Drawing.Point(8, 52);
			this.historyview1_valid_string.Name = "historyview1_valid_string";
			this.historyview1_valid_string.Size = new System.Drawing.Size(551, 19);
			this.historyview1_valid_string.TabIndex = 0;
			// 
			// cancel_button
			// 
			this.cancel_button.Location = new System.Drawing.Point(407, 279);
			this.cancel_button.Name = "cancel_button";
			this.cancel_button.Size = new System.Drawing.Size(75, 23);
			this.cancel_button.TabIndex = 1;
			this.cancel_button.Text = "Cancel(&C)";
			this.cancel_button.UseVisualStyleBackColor = true;
			this.cancel_button.Click += new System.EventHandler(this.cancel_button_Click);
			// 
			// ok_button
			// 
			this.ok_button.Location = new System.Drawing.Point(488, 279);
			this.ok_button.Name = "ok_button";
			this.ok_button.Size = new System.Drawing.Size(75, 23);
			this.ok_button.TabIndex = 2;
			this.ok_button.Text = "OK(&O)";
			this.ok_button.UseVisualStyleBackColor = true;
			this.ok_button.Click += new System.EventHandler(this.ok_button_Click);
			// 
			// OptionDialog
			// 
			this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 12F);
			this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
			this.ClientSize = new System.Drawing.Size(576, 314);
			this.Controls.Add(this.ok_button);
			this.Controls.Add(this.cancel_button);
			this.Controls.Add(this.tabControl1);
			this.Name = "OptionDialog";
			this.Text = "OptionDialog";
			this.Load += new System.EventHandler(this.OptionDialog_Load);
			this.tabControl1.ResumeLayout(false);
			this.tabPage2.ResumeLayout(false);
			this.tabPage2.PerformLayout();
			this.tabPage4.ResumeLayout(false);
			this.tabPage4.PerformLayout();
			this.ResumeLayout(false);

		}

		#endregion

		private System.Windows.Forms.TabControl tabControl1;
		private System.Windows.Forms.TabPage tabPage1;
		private System.Windows.Forms.TabPage tabPage2;
		private System.Windows.Forms.Button cancel_button;
		private System.Windows.Forms.Button ok_button;
		private System.Windows.Forms.ListView action_list;
		private System.Windows.Forms.TabPage tabPage3;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.TextBox new_key;
		private System.Windows.Forms.TextBox old_key;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Button assign_button;
		private System.Windows.Forms.TabPage tabPage4;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.TextBox historyview2_valid_string;
		private System.Windows.Forms.TextBox historyview1_valid_string;
	}
}

==> SCFiler2-0.12.zip: SCFiler2/SCFiler2/OptionDialog.Designer.cs <==
﻿namespace SCFiler2 {
	partial class OptionDialog {
		/// <summary>
		/// 必要なデザイナ変数です。
		/// </summary>
		private System.ComponentModel.IContainer components = null;

		/// <summary>
		/// 使用中のリソースをすべてクリーンアップします。
		/// </summary>
		/// <param name="disposing">マネージ リソースが破棄される場合 true、破棄されない場合は false です。</param>
		protected override void Dispose(bool disposing) {
			if (disposing && (components != null)) {
				components.Dispose();
			}
			base.Dispose(disposing);
		}

		#region Windows フォーム デザイナで生成されたコード

		/// <summary>
		/// デザイナ サポートに必要なメソッドです。このメソッドの内容を
		/// コード エディタで変更しないでください。
		/// </summary>
		private void InitializeComponent() {
			this.tabControl1 = new System.Windows.Forms.TabControl();
			this.tabPage1 = new System.Windows.Forms.TabPage();
			this.tabPage2 = new System.Windows.Forms.TabPage();
			this.assign_button = new System.Windows.Forms.Button();
			this.label2 = new System.Windows.Forms.Label();
			this.label1 = new System.Windows.Forms.Label();
			this.new_key = new System.Windows.Forms.TextBox();
			this.old_key = new System.Windows.Forms.TextBox();
			this.action_list = new System.Windows.Forms.ListView();
			this.tabPage3 = new System.Windows.Forms.TabPage();
			this.tabPage4 = new System.Windows.Forms.TabPage();
			this.label5 = new System.Windows.Forms.Label();
			this.label4 = new System.Windows.Forms.Label();
			this.label3 = new System.Windows.Forms.Label();
			this.historyview2_valid_string = new System.Windows.Forms.TextBox();
			this.historyview1_valid_string = new System.Windows.Forms.TextBox();
			this.cancel_button = new System.Windows.Forms.Button();
			this.ok_button = new System.Windows.Forms.Button();
			this.checkbox_change_drive_by_numkey = new System.Windows.Forms.CheckBox();
			this.tabControl1.SuspendLayout();
			this.tabPage2.SuspendLayout();
			this.tabPage3.SuspendLayout();
			this.tabPage4.SuspendLayout();
			this.SuspendLayout();
			// 
			// tabControl1
			// 
			this.tabControl1.Controls.Add(this.tabPage1);
			this.tabControl1.Controls.Add(this.tabPage2);
			this.tabControl1.Controls.Add(this.tabPage3);
			this.tabControl1.Controls.Add(this.tabPage4);
			this.tabControl1.Dock = System.Windows.Forms.DockStyle.Top;
			this.tabControl1.Location = new System.Drawing.Point(0, 0);
			this.tabControl1.Name = "tabControl1";
			this.tabControl1.SelectedIndex = 0;
			this.tabControl1.Size = new System.Drawing.Size(576, 273);
			this.tabControl1.TabIndex = 0;
			// 
			// tabPage1
			// 
			this.tabPage1.Location = new System.Drawing.Point(4, 21);
			this.tabPage1.Name = "tabPage1";
			this.tabPage1.Padding = new System.Windows.Forms.Padding(3);
			this.tabPage1.Size = new System.Drawing.Size(568, 248);
			this.tabPage1.TabIndex = 0;
			this.tabPage1.Text = "一般設定";
			this.tabPage1.UseVisualStyleBackColor = true;
			// 
			// tabPage2
			// 
			this.tabPage2.Controls.Add(this.assign_button);
			this.tabPage2.Controls.Add(this.label2);
			this.tabPage2.Controls.Add(this.label1);
			this.tabPage2.Controls.Add(this.new_key);
			this.tabPage2.Controls.Add(this.old_key);
			this.tabPage2.Controls.Add(this.action_list);
			this.tabPage2.Location = new System.Drawing.Point(4, 21);
			this.tabPage2.Name = "tabPage2";
			this.tabPage2.Padding = new System.Windows.Forms.Padding(3);
			this.tabPage2.Size = new System.Drawing.Size(568, 248);
			this.tabPage2.TabIndex = 1;
			this.tabPage2.Text = "キー割り当て(1)";
			this.tabPage2.UseVisualStyleBackColor = true;
			// 
			// assign_button
			// 
			this.assign_button.Location = new System.Drawing.Point(443, 140);
			this.assign_button.Name = "assign_button";
			this.assign_button.Size = new System.Drawing.Size(75, 23);
			this.assign_button.TabIndex = 5;
			this.assign_button.Text = "割り当て(&A)";
			this.assign_button.UseVisualStyleBackColor = true;
			this.assign_button.Click += new System.EventHandler(this.assign_button_Click);
			// 
			// label2
			// 
			this.label2.AutoSize = true;
			this.label2.Location = new System.Drawing.Point(300, 100);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(102, 12);
			this.label2.TabIndex = 4;
			this.label2.Text = "新しく割り当てるキー";
			// 
			// label1
			// 
			this.label1.AutoSize = true;
			this.label1.Location = new System.Drawing.Point(300, 28);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(137, 12);
			this.label1.TabIndex = 3;
			this.label1.Text = "現在割り当てられているキー";
			// 
			// new_key
			// 
			this.new_key.ImeMode = System.Windows.Forms.ImeMode.Off;
			this.new_key.Location = new System.Drawing.Point(302, 115);
			this.new_key.Name = "new_key";
			this.new_key.Size = new System.Drawing.Size(216, 19);
			this.new_key.TabIndex = 2;
			this.new_key.KeyPress += new System.Windows.Forms.KeyPressEventHandler(this.new_key_KeyPress);
			this.new_key.TextChanged += new System.EventHandler(this.new_key_TextChanged);
			this.new_key.KeyDown += new System.Windows.Forms.KeyEventHandler(this.new_key_KeyDown);
			// 
			// old_key
			// 
			this.old_key.Location = new System.Drawing.Point(302, 43);
			this.old_key.Name = "old_key";
			this.old_key.Size = new System.Drawing.Size(216, 19);
			this.old_key.TabIndex = 1;
			// 
			// action_list
			// 
			this.action_list.FullRowSelect = true;
			this.action_list.HeaderStyle = System.Windows.Forms.ColumnHeaderStyle.None;
			this.action_list.HideSelection = false;
			this.action_list.LabelWrap = false;
			this.action_list.Location = new System.Drawing.Point(8, 43);
			this.action_list.MultiSelect = false;
			this.action_list.Name = "action_list";
			this.action_list.Size = new System.Drawing.Size(256, 189);
			this.action_list.TabIndex = 0;
			this.action_list.UseCompatibleStateImageBehavior = false;
			this.action_list.View = System.Windows.Forms.View.Details;
			this.action_list.SelectedIndexChanged += new System.EventHandler(this.action_list_SelectedIndexChanged);
			// 
			// tabPage3
			// 
			this.tabPage3.Controls.Add(this.checkbox_change_drive_by_numkey);
			this.tabPage3.Location = new System.Drawing.Point(4, 21);
			this.tabPage3.Name = "tabPage3";
			this.tabPage3.Padding = new System.Windows.Forms.Padding(3);
			this.tabPage3.Size = new System.Drawing.Size(568, 248);
			this.tabPage3.TabIndex = 2;
			this.tabPage3.Text = "キー割り当て(2)";
			this.tabPage3.UseVisualStyleBackColor = true;
			// 
			// tabPage4
			// 
			this.tabPage4.Controls.Add(this.label5);
			this.tabPage4.Controls.Add(this.label4);
			this.tabPage4.Controls.Add(this.label3);
			this.tabPage4.Controls.Add(this.historyview2_valid_string);
			this.tabPage4.Controls.Add(this.historyview1_valid_string);
			this.tabPage4.Location = new System.Drawing.Point(4, 21);
			this.tabPage4.Name = "tabPage4";
			this.tabPage4.Padding = new System.Windows.Forms.Padding(3);
			this.tabPage4.Size = new System.Drawing.Size(568, 248);
			this.tabPage4.TabIndex = 3;
			this.tabPage4.Text = "履歴ビュー";
			this.tabPage4.UseVisualStyleBackColor = true;
			// 
			// label5
			// 
			this.label5.AutoSize = true;
			this.label5.Location = new System.Drawing.Point(8, 81);
			this.label5.Name = "label5";
			this.label5.Size = new System.Drawing.Size(61, 12);
			this.label5.TabIndex = 4;
			this.label5.Text = "履歴ビュー2";
			// 
			// label4
			// 
			this.label4.AutoSize = true;
			this.label4.Location = new System.Drawing.Point(8, 37);
			this.label4.Name = "label4";
			this.label4.Size = new System.Drawing.Size(61, 12);
			this.label4.TabIndex = 3;
			this.label4.Text = "履歴ビュー1";
			// 
			// label3
			// 
			this.label3.AutoSize = true;
			this.label3.Location = new System.Drawing.Point(8, 12);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(456, 12);
			this.label3.TabIndex = 2;
			this.label3.Text = "履歴ビューへ登録する拡張子（セミコロン(;)区切りで、ドット付きで記入してください）　例：.mp3;.txt";
			// 
			// historyview2_valid_string
			// 
			this.historyview2_valid_string.Location = new System.Drawing.Point(8, 96);
			this.historyview2_valid_string.Name = "historyview2_valid_string";
			this.historyview2_valid_string.Size = new System.Drawing.Size(551, 19);
			this.historyview2_valid_string.TabIndex = 1;
			// 
			// historyview1_valid_string
			// 
			this.historyview1_valid_string.Location = new System.Drawing.Point(8, 52);
			this.historyview1_valid_string.Name = "historyview1_valid_string";
			this.historyview1_valid_string.Size = new System.Drawing.Size(551, 19);
			this.historyview1_valid_string.TabIndex = 0;
			// 
			// cancel_button
			// 
			this.cancel_button.Location = new System.Drawing.Point(407, 279);
			this.cancel_button.Name = "cancel_button";
			this.cancel_button.Size = new System.Drawing.Size(75, 23);
			this.cancel_button.TabIndex = 1;
			this.cancel_button.Text = "Cancel(&C)";
			this.cancel_button.UseVisualStyleBackColor = true;
			this.cancel_button.Click += new System.EventHandler(this.cancel_button_Click);
			// 
			// ok_button
			// 
			this.ok_button.Location = new System.Drawing.Point(488, 279);
			this.ok_button.Name = "ok_button";
			this.ok_button.Size = new System.Drawing.Size(75, 23);
			this.ok_button.TabIndex = 2;
			this.ok_button.Text = "OK(&O)";
			this.ok_button.UseVisualStyleBackColor = true;
			this.ok_button.Click += new System.EventHandler(this.ok_button_Click);
			// 
			// checkbox_change_drive_by_numkey
			// 
			this.checkbox_change_drive_by_numkey.AutoSize = true;
			this.checkbox_change_drive_by_numkey.Location = new System.Drawing.Point(8, 6);
			this.checkbox_change_drive_by_numkey.Name = "checkbox_change_drive_by_numkey";
			this.checkbox_change_drive_by_numkey.Size = new System.Drawing.Size(288, 16);
			this.checkbox_change_drive_by_numkey.TabIndex = 0;
			this.checkbox_change_drive_by_numkey.Text = "数字キーでドライブを切り替える　（3→C:\\ 　4→D:\\ …）";
			this.checkbox_change_drive_by_numkey.UseVisualStyleBackColor = true;
			// 
			// OptionDialog
			// 
			this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 12F);
			this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
			this.ClientSize = new System.Drawing.Size(576, 314);
			this.Controls.Add(this.ok_button);
			this.Controls.Add(this.cancel_button);
			this.Controls.Add(this.tabControl1);
			this.Name = "OptionDialog";
			this.Text = "OptionDialog";
			this.Load += new System.EventHandler(this.OptionDialog_Load);
			this.tabControl1.ResumeLayout(false);
			this.tabPage2.ResumeLayout(false);
			this.tabPage2.PerformLayout();
			this.tabPage3.ResumeLayout(false);
			this.tabPage3.PerformLayout();
			this.tabPage4.ResumeLayout(false);
			this.tabPage4.PerformLayout();
			this.ResumeLayout(false);

		}

		#endregion

		private System.Windows.Forms.TabControl tabControl1;
		private System.Windows.Forms.TabPage tabPage1;
		private System.Windows.Forms.TabPage tabPage2;
		private System.Windows.Forms.Button cancel_button;
		private System.Windows.Forms.Button ok_button;
		private System.Windows.Forms.ListView action_list;
		private System.Windows.Forms.TabPage tabPage3;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.TextBox new_key;
		private System.Windows.Forms.TextBox old_key;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Button assign_button;
		private System.Windows.Forms.TabPage tabPage4;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.TextBox historyview2_valid_string;
		private System.Windows.Forms.TextBox historyview1_valid_string;
		private System.Windows.Forms.CheckBox checkbox_change_drive_by_numkey;
	}
}
